@@ -9,6 +9,7 @@ import (
 	"github.com/ViaQ/logerr/kverrors"
 	"github.com/ViaQ/logerr/log"
 	v1 "k8s.io/api/core/v1"
+	apierrors "k8s.io/apimachinery/pkg/api/errors"
 	"k8s.io/apimachinery/pkg/api/resource"
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/client-go/util/retry"
@@ -69,6 +70,10 @@ func (er *ElasticsearchRequest) UpdateClusterStatus() error {
 		return err
 	}
 
+	if err := er.updateStorageConditions(clusterStatus); err != nil {
+		return err
+	}
+
 	if !reflect.DeepEqual(clusterStatus, cluster.Status) {
 		nretries := -1
 		retryErr := retry.RetryOnConflict(retry.DefaultRetry, func() error {
@@ -277,6 +282,127 @@ func (er *ElasticsearchRequest) updateNodeConditions(status *api.ElasticsearchSt
 	return nil
 }
 
+func (er *ElasticsearchRequest) updateStorageConditions(status *api.ElasticsearchStatus) error {
+	ll := er.L()
+
+	emptySpecVol := api.ElasticsearchStorageSpec{}
+	structureStatus, nameStatus, sizeStatus := v1.ConditionFalse, v1.ConditionFalse, v1.ConditionFalse
+
+	nodeNames := []string{}
+	clusterNodes := nodes[nodeMapKey(er.cluster.GetName(), er.cluster.GetNamespace())]
+
+	for _, node := range clusterNodes {
+		nodeNames = append(nodeNames, node.name())
+	}
+
+	for _, node := range er.cluster.Spec.Nodes {
+		nodeName := nodeNameContains(node.GenUUID, nodeNames)
+
+		if nodeName == "" {
+			ll.Info("Unable to find appropriate node to compare storage spec.")
+			continue
+		}
+
+		specVol := node.Storage
+		current := &v1.PersistentVolumeClaim{}
+		claimName := fmt.Sprintf("%s-%s", er.cluster.Name, nodeName)
+
+		isUsingPVCStorageSpec := true
+		isEphemeralStorageSpec := reflect.DeepEqual(specVol, emptySpecVol) || specVol.Size == nil
+
+		retryErr := retry.RetryOnConflict(retry.DefaultRetry, func() error {
+			if err := er.client.Get(context.TODO(), types.NamespacedName{Name: claimName, Namespace: er.cluster.Namespace}, current); err != nil {
+				if !apierrors.IsNotFound(err) {
+					return kverrors.Wrap(err, "failed to get PVC", "claim", claimName)
+				}
+				isUsingPVCStorageSpec = false
+			}
+
+			if isEphemeralStorageSpec && !isUsingPVCStorageSpec {
+				return nil
+			}
+
+			if !isEphemeralStorageSpec != isUsingPVCStorageSpec {
+				structureStatus = v1.ConditionTrue
+				return nil
+			}
+
+			// Generally, this won't last very long with the exception of the case of
+			// moving from ephermeral storage to a persistent one. Since the volume is
+			// never created after the intial create, a PVC should never remain in the
+			// the pending state for a long period of time with the exception of this case.
+			isPVCPending := reflect.DeepEqual(current.Status.Phase, v1.ClaimPending)
+			if isUsingPVCStorageSpec && isPVCPending {
+				structureStatus = v1.ConditionTrue
+				return nil
+			}
+
+			isDefaultName := specVol.StorageClassName == nil && current.Spec.StorageClassName != nil
+			if !isDefaultName && !reflect.DeepEqual(current.Spec.StorageClassName, specVol.StorageClassName) {
+				nameStatus = v1.ConditionTrue
+			}
+
+			currentSize := current.Spec.Resources.Requests.Storage()
+			if currentSize != nil && specVol.Size != nil {
+				if !currentSize.Equal(*specVol.Size) {
+					sizeStatus = v1.ConditionTrue
+				}
+			} else if currentSize != nil || specVol.Size != nil {
+				sizeStatus = v1.ConditionTrue
+			}
+
+			return nil
+		})
+
+		if retryErr != nil {
+			ll.Error(retryErr, "Unable to get PVC")
+		}
+	}
+
+	updateESNodeCondition(status, &api.ClusterCondition{
+		Type:               api.StorageStructure,
+		Status:             structureStatus,
+		LastTransitionTime: metav1.Now(),
+		Reason:             "StorageStructureChangeIgnored",
+		Message:            "Changing the storage structure for a custom resource is not supported",
+	})
+
+	updateESNodeCondition(status, &api.ClusterCondition{
+		Type:               api.StorageClassName,
+		Status:             nameStatus,
+		LastTransitionTime: metav1.Now(),
+		Reason:             "StorageClassNameChangeIgnored",
+		Message:            "Changing the storage class name for a custom resource is not supported",
+	})
+
+	updateESNodeCondition(status, &api.ClusterCondition{
+		Type:               api.StorageSize,
+		Status:             sizeStatus,
+		LastTransitionTime: metav1.Now(),
+		Reason:             "StorageSizeChangeIgnored",
+		Message:            "Resizing the storage for a custom resource is not supported",
+	})
+
+	return nil
+}
+
+func nodeNameContains(uuid *string, names []string) string {
+	nodeName := ""
+
+	if uuid == nil {
+		return nodeName
+	}
+
+	for _, name := range names {
+		if strings.Contains(name, *uuid) {
+			nodeName = name
+			break
+		}
+	}
+
+	return nodeName
+}
+
 func (er *ElasticsearchRequest) pruneMissingNodes(status *api.ElasticsearchStatus) error {
 	cluster := er.cluster
 	ll := er.L()
@@ -853,7 +979,23 @@ func updateInvalidReplicationCondition(status *api.ElasticsearchStatus, value v1
 	})
 }
 
-func (er *ElasticsearchRequest) UpdateDegradedCondition(value bool, reason, message string) {
+func updateInvalidScaleDownCondition(status *api.ElasticsearchStatus, value v1.ConditionStatus) bool {
+	var message string
+	var reason string
+	if value == v1.ConditionTrue {
+		message = "Data node scale down rate is too high based on minimum number of replicas for all indices"
+		reason = "Invalid Settings"
+	}
+
+	return updateESNodeCondition(status, &api.ClusterCondition{
+		Type:    api.InvalidRedundancy,
+		Status:  value,
+		Reason:  reason,
+		Message: message,
+	})
+}
+
+func (er *ElasticsearchRequest) UpdateDegradedCondition(value bool, reason, message string) error {
 	cluster := er.cluster
 
 	statusValue := v1.ConditionFalse
@@ -862,7 +1004,7 @@ func (er *ElasticsearchRequest) UpdateDegradedCondition(value bool, reason, mess
 		statusValue = v1.ConditionTrue
 	}
 
-	updateConditionWithRetry(
+	return updateConditionWithRetry(
 		cluster,
 		statusValue,
 		func(status *api.ElasticsearchStatus, statusValue v1.ConditionStatus) bool {
